@@ -1,16 +1,17 @@
 """Module for manage API"""
 import json
-import os
+from pathlib import Path
+import re
 import urllib.request
 import typing
-from typing import Any, Dict, List, Optional, Type
+from typing import Any, List, Optional, Type, Union
 import warnings
 
 from .annealing import AnnealingTask, AnnealingResult
 from .data import ExecutionRequest, ExecutionRequestEncoder, Status, TaskData, TaskListData
 from .device import Device
-from .task import CloudTask, TaskIter, TaskList
-from .local import make_localtask
+from .task import CloudTask, CloudTaskOptions, TaskIter, TaskList
+from .local import make_localtask, LocalTaskOptions
 
 from .datafactory import make_executiondata, make_result
 
@@ -43,12 +44,18 @@ class Api:
             body = res.read()
         return json.loads(body)
 
+    def save_to_file(self, suffix: str = '') -> None:
+        """Save API to file."""
+        key_path = _get_apikey_path(suffix)
+        parent_dir = key_path.parent
+        parent_dir.mkdir(exist_ok=True)
+        key_path.write_text(self.api_key)
+
     def save_api(self) -> None:
         """Save API to file."""
-        d = os.path.join(os.environ["HOME"], ".bqcloud")
-        os.makedirs(d, exist_ok=True)
-        with open(os.path.join(d, "api_key"), "w") as f:
-            f.write(self.api_key)
+        warnings.warn("Api.save_api is deprecated. Use Api.save_to_file.",
+                      DeprecationWarning)
+        self.save_to_file()
 
     def credit(self) -> str:
         """Get credit."""
@@ -68,8 +75,7 @@ class Api:
                                 execdata,
                                 json_encoder=ExecutionRequestEncoder)
         taskdata = TaskData.from_dict(res['task'])
-        result = make_result(res.get('result', {}),
-                             Device(taskdata.device))
+        result = make_result(res.get('result', {}), Device(taskdata.device))
         return CloudTask(self, taskdata, result)
 
     def annealing(self, qubo: List[List[float]], chain_strength: int,
@@ -83,18 +89,19 @@ class Api:
         })
         return AnnealingResult(**res)
 
-    def execute(self,
-                c: 'Circuit',
-                device: Device,
-                shots: int,
-                group: Optional[str] = None,
-                send_email: bool = False) -> 'AbstractTask':
+    def execute(
+        self,
+        c: 'Circuit',
+        device: Device,
+        shots: int,
+        options: Union[LocalTaskOptions, CloudTaskOptions, None] = None
+    ) -> 'AbstractTask':
         """Create new task and execute the task."""
+        if options is None:
+            options = {}
         if device.value == 'local':
-            if group is not None or send_email:
-                warnings.warn('Arguments `group` and `send_email` is ignored in local device.')
-            return make_localtask(c, shots)
-        execdata = make_executiondata(c, device, shots, group, send_email)
+            return make_localtask(c, shots, options)
+        execdata = make_executiondata(c, device, shots, options)
         return self.post_executiondata(execdata)
 
     def annealing_tasks(self, index: int = 0) -> List[AnnealingTask]:
@@ -159,14 +166,36 @@ class Api:
                         option_fields=option_fields)
 
 
-def load_api() -> Api:
+def create_api(api_key: str) -> Api:
+    """Create API from API key."""
+    return Api(api_key)
+
+
+def load_api(suffix: str = '') -> Api:
     """Load API from file."""
-    with open(os.path.join(os.environ["HOME"], ".bqcloud/api_key")) as f:
-        return Api(f.read().strip())
+    key_path = _get_apikey_path(suffix)
+    api_key = key_path.read_text().strip()
+    return create_api(api_key)
 
 
-def register_api(api_key: str) -> Api:
+def register_api(api_key: str, suffix: str = '') -> Api:
     """Save and return API."""
     api = Api(api_key)
-    api.save_api()
+    api.save_to_file(suffix)
     return api
+
+
+def _check_suffix(suffix: str) -> bool:
+    """Check validity of suffix"""
+    return bool(re.match('^[-_a-zA-Z0-9]*$', suffix))
+
+
+def _get_apikey_path(suffix: str) -> Path:
+    if not _check_suffix(suffix):
+        raise ValueError(f'Invalid suffix "{suffix}" is specified.')
+    base = Path.home().joinpath(".bqcloud")
+    if suffix:
+        key_path = base.joinpath("api_key_" + suffix)
+    else:
+        key_path = base.joinpath("api_key")
+    return key_path
