@@ -4,5 +4,7 @@ from enum import Enum
 class Device(str, Enum):
     Local = "local"
     IonQDevice = "aws/ionq/ionQdevice"
-    Aspen8 = "aws/rigetti/Aspen-8"
     Aspen9 = "aws/rigetti/Aspen-9"
+    SimSv1 = "aws/amazon/sv1"
+    SimTn1 = "aws/amazon/tn1"
+    SimDm1 = "aws/amazon/dm1"
